summaryrefslogtreecommitdiffstats
path: root/Lib/idlelib/idle_test/mock_idle.py
diff options
context:
space:
mode:
authorLouie Lu <git@louie.lu>2017-07-14 00:35:48 (GMT)
committerterryjreedy <tjreedy@udel.edu>2017-07-14 00:35:48 (GMT)
commit9b622fb90331f259894e6edb29b5c64b9366491a (patch)
tree8be2cdae73c63fb902e4a20863b0a86b8d8c87d9 /Lib/idlelib/idle_test/mock_idle.py
parentc40ad03bf2693b4af539978f1274e57b85367547 (diff)
downloadcpython-9b622fb90331f259894e6edb29b5c64b9366491a.zip
cpython-9b622fb90331f259894e6edb29b5c64b9366491a.tar.gz
cpython-9b622fb90331f259894e6edb29b5c64b9366491a.tar.bz2
bpo-30870: IDLE: Add configdialog fontlist selection unittest (#2666)
Initial patch by Louie Lu.
Diffstat (limited to 'Lib/idlelib/idle_test/mock_idle.py')
-rw-r--r--Lib/idlelib/idle_test/mock_idle.py19
1 files changed, 10 insertions, 9 deletions
diff --git a/Lib/idlelib/idle_test/mock_idle.py b/Lib/idlelib/idle_test/mock_idle.py
index c7b49ef..8f3147b 100644
--- a/Lib/idlelib/idle_test/mock_idle.py
+++ b/Lib/idlelib/idle_test/mock_idle.py
@@ -6,24 +6,25 @@ Attributes and methods will be added as needed for tests.
from idlelib.idle_test.mock_tk import Text
class Func:
- '''Mock function captures args and returns result set by test.
+ '''Record call, capture args, return/raise result set by test.
- Attributes:
- self.called - records call even if no args, kwds passed.
- self.result - set by init, returned by call.
- self.args - captures positional arguments.
- self.kwds - captures keyword arguments.
+ When mock function is called, set or use attributes:
+ self.called - increment call number even if no args, kwds passed.
+ self.args - capture positional arguments.
+ self.kwds - capture keyword arguments.
+ self.result - return or raise value set in __init__.
- Most common use will probably be to mock methods.
+ Most common use will probably be to mock instance methods.
+ Given class instance, can set and delete as instance attribute.
Mock_tk.Var and Mbox_func are special variants of this.
'''
def __init__(self, result=None):
- self.called = False
+ self.called = 0
self.result = result
self.args = None
self.kwds = None
def __call__(self, *args, **kwds):
- self.called = True
+ self.called += 1
self.args = args
self.kwds = kwds
if isinstance(self.result, BaseException):